library provider_collection_notifiers;

import 'package:flutter/foundation.dart';

abstract class DataRepository {}

abstract class CollectionChangeNotifier<T, R extends DataRepository>
    extends ChangeNotifier {
  CollectionChangeNotifier(R repo, {T data})
      : _repo = repo,
        _data = data;
  final R _repo;
  R get repo => _repo;

  T _data;
  T get data => _data;

  @protected
  set data(T newData) {
    _data = newData;
  }

  bool _isInProgress = false;
  bool get isInProgress => _isInProgress;

  @protected
  set isInProgress(bool value) {
    _isInProgress = value;
    notifyListeners();
  }

  @mustCallSuper
  Future fetchData() async {
    if (dataIsEmpty()) {
      isInProgress = true;
    }
  }

  bool dataIsEmpty();

  Future refreshData();
}
